# Generated by Django 3.2.6 on 2021-08-14 21:38

from django.db import migrations
import django.db.models.deletion
import iranian_cities.fields


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0004_remove_abadi_shhahr'),
        ('test_app', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='testmodel',
            name='abadi',
            field=iranian_cities.fields.AbadiField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.abadi'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='bakhsh',
            field=iranian_cities.fields.BakhshField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.bakhsh'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='dehestan',
            field=iranian_cities.fields.DehestanField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.dehestan'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='shahr',
            field=iranian_cities.fields.ShahrField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.shahr'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='shahrestan',
            field=iranian_cities.fields.ShahrestanField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.shahrestan'),
            preserve_default=False,
        ),
    ]
