# Generated by Django 3.2.6 on 2021-08-14 21:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0002_auto_20210814_2138'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='testmodel',
            name='abadi',
        ),
        migrations.RemoveField(
            model_name='testmodel',
            name='dehestan',
        ),
        migrations.RemoveField(
            model_name='testmodel',
            name='shahr',
        ),
    ]
