# Generated by Django 3.2.6 on 2021-08-14 21:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='dehestan',
            old_name='shhahr',
            new_name='shahr',
        ),
    ]
