# Generated by Django 3.2.6 on 2021-08-14 21:07

from django.db import migrations, models
import django.db.models.deletion
import iranian_cities.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('iranian_cities', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ostan', iranian_cities.fields.OstanField(on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.ostan')),
            ],
        ),
    ]
