# Generated by Django 3.2.6 on 2021-08-14 21:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0003_remove_dehestan_shahr'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='abadi',
            name='shhahr',
        ),
    ]
